# steamBirthday
Get the date you created your Steam account
![](images/steamBday.jpg)

This program uses the Steam API 

[Steam Developer Documentation](https://steamcommunity.com/dev)
Grab your API key! 

## How to run steamBirthday
- Run through terminal 
`python main.py --steamid {YOUR STEAM ID}`

### Clone this repo 
`git clone https://github.com/<your-github-username>/steamBirthday.git`
    

[Don't know your SteamID? Click here](https://www.maketecheasier.com/find-steam-id/)
